cpDNAterms: Chloroplast DNA (cpDNA) Search Terms

cpDNAtermsR Documentation

Chloroplast DNA (cpDNA) Search Terms

Description

A data frame containing search terms for Chloroplast loci. Can be subset for loci of interest. Columns are as follows and users should follow the column format if they wish to add search terms using the MergeSearchTerms function:

Usage

cpDNAterms

Format

A data frame of of 391 rows and 3 columns

  • Feature: Feature name, FASTA files will be written with this name.

  • Type: Type of feature, either CDS,tRNA,rRNA.

  • Name: Name of synonym for a feature to search for.

See Also

MergeSearchTerms


AnnotationBustR documentation built on Sept. 1, 2026, 1:09 a.m.